@@ -279,6 +279,11 @@ class DepositIntegration:
         if you plan to return a success response. If `transaction` is saved to the DB but a
         failure response is returned, Polaris will return a 500 error to the user.
 
+        Polaris responds to requests with the standard status code according the SEP. However,
+        if you would like to return a custom error code in the range of 400-599 you may raise
+        an ``rest_framework.exceptions.APIException``. For example, you could return a 503
+        status code by raising an ``APIException("service unavailable", status_code=503)``.
+
         `Deposit no additional information needed`_
 
         The success response. Polaris creates most of the attributes described in this response.
@@ -328,6 +333,11 @@ class DepositIntegration:
         Stellar account `that does not require multiple signatures`, and save the secret key
         of the created account to ``transaction.channel_seed``.
 
+        This channel account must only be used as the source account for transactions related to the
+        ``Transaction`` object passed. It also must not be used to submit transactions by any service
+        other than Polaris. If it is, the outstanding transactions will be invalidated due to bad
+        sequence numbers.
+
         If this integration function is called, the deposit payment represented by ``transaction``
         requires multiple signatures in order to be successfully submitted to the Stellar network.
         The anchored asset's distribution account may or may not be in that set of signatures
@@ -451,10 +461,8 @@ class WithdrawalIntegration:
         .. _/withdraw: https://github.com/stellar/stellar-protocol/blob/master/ecosystem/sep-0006.md#withdraw
         .. _Withdraw no additional information needed: https://github.com/stellar/stellar-protocol/blob/master/ecosystem/sep-0006.md#1-success-no-additional-information-needed-1
 
-        Process the request arguments passed to the `/withdraw`_ endpoint and return one of the
-        following responses outlined below as a dictionary. Save `transaction` to the DB
-        if you plan to return a success response. If `transaction` is saved to the DB but a
-        failure response is returned, Polaris will return a 500 error to the user.
+        Same as ``DepositIntegration.process_sep6_request`` except for the case below.
+        Specifically, the ``how`` attribute should not be included.
 
         `Withdraw no additional information needed`_
 
@@ -468,8 +476,9 @@ class WithdrawalIntegration:
                 }
             }
 
-        You may also return the `Customer information needed`_ and `Customer Information Status`_
-        responses as described in ``DepositIntegration.process_sep6_request``.
+        In addition to this response, uou may also return the `Customer information needed`_
+        and `Customer Information Status`_ responses as described in
+        ``DepositIntegration.process_sep6_request``.
         """
         raise NotImplementedError(
             "`process_sep6_request` must be implemented if SEP-6 is active"
