@@ -5,10 +5,12 @@ class PolarisSameSiteMiddleware:
     :class:`django.http.HttpResponse.set_cookie`, which does not
     allow `samesite` values of ``None``.
 
-    Polaris developers MUST add this class to their Django app's
-    ``settings.MIDDLEWARE``. Specifically, the class must be listed
-    `above` :class:`django.contrib.sessions.middleware.SessionMiddleware`,
-    like so:
+    **This is only required if you want to support clients that open
+    interactive URLs in iframes in addition to the recommended strategy
+    of using popups.**
+
+    If used, the class must be listed `above`
+    :class:`django.contrib.sessions.middleware.SessionMiddleware`, like so:
     ::
 
         MIDDLEWARE = [
